socket_set_options.RdEach element of options must be a list containing option and value,
with optional level and type entries. Options are applied in list order.
If a native option fails, the error includes the zero-based count of options
already applied in its applied field.
socket_set_options(socket, options)The socket handle, invisibly.